@@ -1,12 +1,6 @@
 /* FriBidi
  * fribidi-benchmark.c - command line benchmark tool for libfribidi
  *
- * $Id: fribidi-benchmark.c,v 1.8 2009-04-14 03:49:52 behdad Exp $
- * $Author: behdad $
- * $Date: 2009-04-14 03:49:52 $
- * $Revision: 1.8 $
- * $Source: /home/behdad/src/fdo/fribidi/togit/git/../fribidi/fribidi2/bin/fribidi-benchmark.c,v $
- *
  * Authors:
  *   Behdad Esfahbod, 2001, 2002, 2004
  *   Dov Grobgeld, 1999, 2000
@@ -30,12 +24,13 @@
  * Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
  * Boston, MA 02110-1301, USA
  * 
- * For licensing issues, contact <license@farsiweb.info>.
+ * For licensing issues, contact <fribidi.license@gmail.com>.
  */
 
 #include <common.h>
 
 #include <fribidi.h>
+#include <fribidi-deprecated.h>
 
 #include <stdio.h>
 #if STDC_HEADERS+0
@@ -218,6 +213,7 @@ benchmark (
     {
       /* Create a bidi string */
       base = FRIBIDI_PAR_ON;
+FRIBIDI_BEGIN_IGNORE_DEPRECATIONS
       if (!fribidi_log2vis (us, len, &base,
 			    /* output */
 			    out_us, positionVtoL, positionLtoV,
@@ -225,6 +221,7 @@ benchmark (
 	die2
 	  ("something failed in fribidi_log2vis.\n"
 	   "perhaps memory allocation failure.", NULL);
+FRIBIDI_END_IGNORE_DEPRECATIONS
     }
 
   /* stop timer */
