@@ -1,19 +1,13 @@
 /* FriBidi
  * fribidi-run.c - text run data type
  *
- * $Id: fribidi-run.c,v 1.8 2006-01-31 03:23:13 behdad Exp $
- * $Author: behdad $
- * $Date: 2006-01-31 03:23:13 $
- * $Revision: 1.8 $
- * $Source: /home/behdad/src/fdo/fribidi/togit/git/../fribidi/fribidi2/lib/fribidi-run.c,v $
- *
  * Authors:
  *   Behdad Esfahbod, 2001, 2002, 2004
- *   Dov Grobgeld, 1999, 2000
+ *   Dov Grobgeld, 1999, 2000, 2017
  *
  * Copyright (C) 2004 Sharif FarsiWeb, Inc
  * Copyright (C) 2001,2002 Behdad Esfahbod
- * Copyright (C) 1999,2000 Dov Grobgeld
+ * Copyright (C) 1999,2000,2017 Dov Grobgeld
  * 
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -30,7 +24,7 @@
  * Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
  * Boston, MA 02110-1301, USA
  * 
- * For licensing issues, contact <license@farsiweb.info>.
+ * For licensing issues, contact <fribidi.license@gmail.com>.
  */
 
 #include "common.h"
@@ -38,14 +32,8 @@
 #include <fribidi-bidi-types.h>
 
 #include "run.h"
-#include "mem.h"
 #include "bidi-types.h"
 
-#if USE_SIMPLE_MALLOC+0
-#else
-static FriBidiRun *free_runs = NULL;
-#endif
-
 FriBidiRun *
 new_run (
   void
@@ -53,54 +41,17 @@ new_run (
 {
   register FriBidiRun *run;
 
-#if USE_SIMPLE_MALLOC+0
   run = fribidi_malloc (sizeof (FriBidiRun));
-#else /* !USE_SIMPLE_MALLOC */
-  if (free_runs)
-    {
-      run = free_runs;
-      free_runs = run->next;
-    }
-  else
-    {
-      static FriBidiMemChunk *run_mem_chunk = NULL;
-
-      if UNLIKELY
-	(!run_mem_chunk)
-	 run_mem_chunk = fribidi_chunk_new_for_type (FriBidiRun);
-
-      if LIKELY
-	(run_mem_chunk)
-	run = fribidi_chunk_new (FriBidiRun, run_mem_chunk);
-      else
-	run = NULL;
-    }
-#endif /* !USE_SIMPLE_MALLOC */
 
   if LIKELY
     (run)
     {
-      run->len = run->pos = run->level = 0;
-      run->next = run->prev = NULL;
+      run->len = run->pos = run->level = run->isolate_level = 0;
+      run->next = run->prev = run->prev_isolate = run->next_isolate = NULL;
     }
   return run;
 }
 
-void
-free_run (
-  /* input */
-  FriBidiRun *run
-)
-{
-  fribidi_assert (run);
-#if USE_SIMPLE_MALLOC+0
-  fribidi_free (run);
-#else /* !USE_SIMPLE_MALLOC */
-  run->next = free_runs;
-  free_runs = run;
-#endif /* !USE_SIMPLE_MALLOC */
-}
-
 FriBidiRun *
 new_run_list (
   void
@@ -133,7 +84,6 @@ free_run_list (
 
   fribidi_validate_run_list (run_list);
 
-#if USE_SIMPLE_MALLOC+0
   {
     register FriBidiRun *pp;
 
@@ -146,13 +96,9 @@ free_run_list (
 
 	p = pp;
 	pp = pp->next;
-	free_run (p);
+	fribidi_free (p);
       };
   }
-#else /* !USE_SIMPLE_MALLOC */
-  run_list->prev->next = free_runs;
-  free_runs = run_list;
-#endif /* !USE_SIMPLE_MALLOC */
 }
 
 
@@ -160,6 +106,7 @@ FriBidiRun *
 run_list_encode_bidi_types (
   /* input */
   const FriBidiCharType *bidi_types,
+  const FriBidiBracketType *bracket_types,
   const FriBidiStrIndex len
 )
 {
@@ -179,7 +126,15 @@ run_list_encode_bidi_types (
   for (i = 0; i < len; i++)
     {
       register FriBidiCharType char_type = bidi_types[i];
-      if (char_type != last->type)
+      register FriBidiBracketType bracket_type = FRIBIDI_NO_BRACKET;
+      if (bracket_types)
+        bracket_type = bracket_types[i];
+      
+      if (char_type != last->type
+          || bracket_type != FRIBIDI_NO_BRACKET /* Always separate bracket into single char runs! */
+          || last->bracket_type != FRIBIDI_NO_BRACKET
+          || FRIBIDI_IS_ISOLATE(char_type)
+          )
 	{
 	  run = new_run ();
 	  if UNLIKELY
@@ -189,6 +144,7 @@ run_list_encode_bidi_types (
 	  last->len = run->pos - last->pos;
 	  last->next = run;
 	  run->prev = last;
+          run->bracket_type = bracket_type;
 	  last = run;
 	}
     }
@@ -274,6 +230,7 @@ shadow_run_list (
 	    p->next->prev = r;
 	    r->next = p->next;
 	    r->level = p->level;
+	    r->isolate_level = p->isolate_level;
 	    r->type = p->type;
 	    r->len = p->pos + p->len - pos2;
 	    r->pos = pos2;
@@ -292,7 +249,7 @@ shadow_run_list (
 	      {
 		t = p;
 		p = p->prev;
-		free_run (t);
+		fribidi_free (t);
 	      }
 	  }
       }
@@ -312,7 +269,7 @@ shadow_run_list (
 	/* r needed? */
 	if (r->pos + r->len > pos2)
 	  {
-	    /* cut the begining of r. */
+	    /* cut the beginning of r. */
 	    r->len = r->pos + r->len - pos2;
 	    r->pos = pos2;
 	  }
@@ -324,7 +281,7 @@ shadow_run_list (
 	  {
 	    t = s;
 	    s = s->next;
-	    free_run (t);
+	    fribidi_free (t);
 	  }
       }
     /* before updating the next and prev runs to point to the inserted q,
